Image

Struct Image 

pub struct Image {
    pub src: String,
    pub object_fit: ObjectFit,
    pub style: Style,
    pub break_before: BreakType,
    pub fixed: bool,
    pub wrap: Option<bool>,
    pub min_presence_ahead: f32,
}
Raster image node.

Fields

src: String

Source URL or file path

object_fit: ObjectFit

Object fit mode

style: Style

Style (width, height, borders, etc.)

break_before: BreakType

Whether to break before this element

fixed: bool

Whether this element is rendered on all pages (react-pdf fixed)

wrap: Option<bool>

Whether this element can be split between pages (ignored for images; always false)

min_presence_ahead: f32

Desired minimum remaining presence (in points) after this element.

Implementations

Source

impl Image

pub fn new(src: impl Into<String>) -> Self

Create an image node with the given source.

pub fn with_style(self, style: Style) -> Self

Set the style for the image node.