pub struct Image {
pub src: String,
pub object_fit: ObjectFit,
pub style: Style,
pub break_before: BreakType,
pub fixed: bool,
pub wrap: Option<bool>,
pub min_presence_ahead: f32,
}Expand description
Raster image node.
Fields
src: StringSource URL or file path
object_fit: ObjectFitObject fit mode
style: StyleStyle (width, height, borders, etc.)
break_before: BreakTypeWhether to break before this element
fixed: boolWhether this element is rendered on all pages (react-pdf fixed)
wrap: Option<bool>Whether this element can be split between pages (ignored for images; always false)
min_presence_ahead: f32Desired minimum remaining presence (in points) after this element.
Implementations