pub struct View {
pub style: Style,
pub children: Vec<Component>,
pub break_before: BreakType,
pub id: Option<String>,
pub fixed: bool,
pub wrap: Option<bool>,
pub min_presence_ahead: f32,
}Expand description
Flexbox container.
Fields
style: Stylechildren: Vec<Component>break_before: BreakTypeWhether to break before this element
id: Option<String>fixed: boolwrap: Option<bool>Whether this element can be split between pages (default: true)
min_presence_ahead: f32Desired minimum remaining presence (in points) after this element.
Implementations
Sourceimpl View
impl View
Sourcepub fn with_style(self, style: Style) -> Self
pub fn with_style(self, style: Style) -> Self
Set the style for the view.
Sourcepub fn with_child(self, child: impl Into<Component>) -> Self
pub fn with_child(self, child: impl Into<Component>) -> Self
Append a child and return the view for chaining.